@@ -330,6 +330,13 @@ fourierf <- function(x, K, h)
     period <- frequency(x)
   }
 
+  # Patch for older versions of R that do not have sinpi and cospi functions.
+  if(!exists("sinpi"))
+  {
+    sinpi <- function(x){sin(pi*x)}
+    cospi <- function(x){cos(pi*x)}
+  }
+
   len.p <- length(period)
   if(len.p != length(K))
     stop("Number of periods does not match number of orders")
